==> mx-conky_19.4.tar.xz: mx-conky-19.4/translations/mx-conky_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="45"/>
        <location filename="../mainwindow.cpp" line="303"/>
        <source>MX Conky</source>
        <translation>MX Conky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;This app enables detailed changes to the active conky. It supplements Conky Manager, which should be used for basic settings.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;Questa applicazione consente di modificare dettagliatamente il servizio conky attivo. Si affianca a Conky Manager, che dovrebbe essere utilizzato per le impostazioni di base.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Launch</source>
        <translation>Avvia</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="85"/>
        <source>Run</source>
        <translation>Esegui...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>Undo</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="171"/>
        <source>Edit</source>
        <translation>Edita</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Conky Name</source>
        <translation>Nome Conky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="211"/>
        <source>Conky Manager</source>
        <translation>Conky Manager</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <source>Drag</source>
        <translation>Trascinamento</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>To Resize</source>
        <translation>Per ridimensionare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>+ Left Click</source>
        <translation>+ click sinistro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="281"/>
        <source>To Move</source>
        <translation>Per spostare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="288"/>
        <source>+ Right Click</source>
        <translation>+ click destro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="295"/>
        <source>NOTE: changes last only for the current session</source>
        <translation>NOTA: le modifiche durano solo per la sessione corrente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="365"/>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="387"/>
        <source>Desktop 1</source>
        <translation>Desktop 1</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="410"/>
        <source>All Desktops</source>
        <translation>Tutti i Desktop</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="488"/>
        <source>Day</source>
        <translation>Giorno</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="517"/>
        <location filename="../mainwindow.ui" line="647"/>
        <source>Long</source>
        <translation>Lungo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="546"/>
        <source>Abbreviated name, e.g. Tu</source>
        <translation>Nome abbreviato, ad es. Lu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <location filename="../mainwindow.ui" line="679"/>
        <source>Short</source>
        <translation>Corto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="618"/>
        <source>Month</source>
        <translation>Mese</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="676"/>
        <source>Abbreviated name, e.g. Oct</source>
        <translation>Nome abbreviato, ad es. Ott</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="732"/>
        <source>Colors</source>
        <translation>Colori</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="778"/>
        <source>Default</source>
        <translation>Default</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="830"/>
        <location filename="../mainwindow.ui" line="942"/>
        <location filename="../mainwindow.ui" line="1054"/>
        <location filename="../mainwindow.ui" line="1169"/>
        <location filename="../mainwindow.ui" line="1284"/>
        <location filename="../mainwindow.ui" line="1399"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="893"/>
        <source>Color0 </source>
        <translation>Colore0 </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1005"/>
        <source>Color1 </source>
        <translation>Colore1 </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1117"/>
        <source>Color2 </source>
        <translation>Colore2 </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1232"/>
        <source>Color3 </source>
        <translation>Colore3 </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1347"/>
        <source>Color4 </source>
        <translation>Colore4 </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1455"/>
        <source>About this application</source>
        <translation>Informazioni su questa applicazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1458"/>
        <source>About...</source>
        <translation>Info...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1465"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1481"/>
        <source>Display help </source>
        <translation>Visualizza la guida</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1484"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1491"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1539"/>
        <source>Quit application</source>
        <translation> Chiudi l&apos;applicazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1542"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1549"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>About MX Conky</source>
        <translation>Informazioni su MX Conky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <source>Version: </source>
        <translation>Versione:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>GUI program for configuring Conky in MX Linux</source>
        <translation>Programma per la configurazione di Conky in MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="307"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="329"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="348"/>
        <source>MX Conky Help</source>
        <translation>Aiuto per MX Conky</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="56"/>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Select Conky Manager config file</source>
        <translation>Seleziona il file config di Conky Manager</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Conky Data Update</source>
        <translation>Aggiornamento Concky-Data</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>The MX Conky data set has been updated. &lt;p&gt;&lt;p&gt;                                  Copy from the folder where it is located &lt;a href=&quot;/usr/share/mx-conky-data/themes&quot;&gt;/usr/share/mx-conky-data/themes&lt;/a&gt;                                   whatever you wish to your Home hidden conky folder &lt;a href=&quot;%1/.conky&quot;&gt;~/.conky&lt;/a&gt;.                                   Be careful not to overwrite any conkies you have changed.</source>
        <translation>L&apos;insieme dei dati di MX Conky è stato aggiornato. &lt;p&gt;&lt;p&gt;                                  Copia dalla cartella dove sono archiviati &lt;a href=&quot;/usr/share/mx-conky-data/themes&quot;&gt;/usr/share/mx-conky-data/themes&lt;/a&gt;                                   qualsiasi cosa ti possa interessare sulla cartella nascosta presente nella Home &lt;a href=&quot;%1/.conky&quot;&gt;~/.conky&lt;/a&gt;.                                   Fa attenzione a non sovrascrivere i conkies che hai modificato.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="100"/>
        <location filename="../main.cpp" line="124"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="101"/>
        <source>Could not find conky-manager, please install it before running mx-conky</source>
        <translation>Non si riesce a trovare conky-manager, installalo prima di eseguire mx-conky</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="125"/>
        <source>No file was selected, quiting program</source>
        <translation>Nessun file è stato selezionato, si chiude il programma</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="136"/>
        <source>You must run this program as normal user</source>
        <translation>Devi avviare questo programma come utente normale</translation>
    </message>
</context>
</TS>

==> mx-conky_21.7.tar.xz: mx-conky-21.7/translations/mx-conky_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="49"/>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>MX Conky</source>
        <translation>MX Conky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;This app enables detailed changes to the active conky. It supplements Conky Manager, which should be used for basic settings.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;Questa applicazione consente di modificare dettagliatamente il servizio conky attivo. Si affianca a Conky Manager, che dovrebbe essere utilizzato per le impostazioni di base.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Launch</source>
        <translation>Avvia</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="85"/>
        <source>Run</source>
        <translation>Esegui...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>Undo</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="171"/>
        <source>Edit</source>
        <translation>Edita</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Conky Name</source>
        <translation>Nome Conky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="211"/>
        <source>Conky Manager</source>
        <translation>Conky Manager</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <source>Drag</source>
        <translation>Trascinamento</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>To Resize</source>
        <translation>Per ridimensionare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>+ Left Click</source>
        <translation>+ click sinistro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="281"/>
        <source>To Move</source>
        <translation>Per spostare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="288"/>
        <source>+ Right Click</source>
        <translation>+ click destro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="295"/>
        <source>NOTE: changes last only for the current session</source>
        <translation>NOTA: le modifiche durano solo per la sessione corrente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="365"/>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="387"/>
        <source>Desktop 1</source>
        <translation>Desktop 1</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="410"/>
        <source>All Desktops</source>
        <translation>Tutti i Desktop</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="488"/>
        <source>Day</source>
        <translation>Giorno</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="517"/>
        <location filename="../mainwindow.ui" line="647"/>
        <source>Long</source>
        <translation>Lungo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="546"/>
        <source>Abbreviated name, e.g. Tu</source>
        <translation>Nome abbreviato, ad es. Lu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <location filename="../mainwindow.ui" line="679"/>
        <source>Short</source>
        <translation>Corto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="618"/>
        <source>Month</source>
        <translation>Mese</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="676"/>
        <source>Abbreviated name, e.g. Oct</source>
        <translation>Nome abbreviato, ad es. Ott</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="732"/>
        <source>Colors</source>
        <translation>Colori</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="778"/>
        <source>Default</source>
        <translation>Default</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="833"/>
        <location filename="../mainwindow.ui" line="948"/>
        <location filename="../mainwindow.ui" line="1063"/>
        <location filename="../mainwindow.ui" line="1181"/>
        <location filename="../mainwindow.ui" line="1299"/>
        <location filename="../mainwindow.ui" line="1417"/>
        <location filename="../mainwindow.ui" line="1532"/>
        <location filename="../mainwindow.ui" line="1647"/>
        <location filename="../mainwindow.ui" line="1762"/>
        <location filename="../mainwindow.ui" line="1877"/>
        <location filename="../mainwindow.ui" line="1992"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="896"/>
        <source>Color0 </source>
        <translation>Colore0 </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1011"/>
        <source>Color1 </source>
        <translation>Colore1 </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1126"/>
        <source>Color2 </source>
        <translation>Colore2 </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1244"/>
        <source>Color3 </source>
        <translation>Colore3 </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1362"/>
        <source>Color4 </source>
        <translation>Colore4 </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1480"/>
        <source>Color5</source>
        <translation type="unfinished">Colore4  {5?}</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1595"/>
        <source>Color6</source>
        <translation type="unfinished">Colore4  {6?}</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1710"/>
        <source>Color7</source>
        <translation type="unfinished">Colore4  {7?}</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1825"/>
        <source>Color8</source>
        <translation type="unfinished">Colore4  {8?}</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1940"/>
        <source>Color9</source>
        <translation type="unfinished">Colore4  {9?}</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2048"/>
        <source>About this application</source>
        <translation>Informazioni su questa applicazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2051"/>
        <source>About...</source>
        <translation>Info...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2058"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2074"/>
        <source>Display help </source>
        <translation>Visualizza la guida</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2077"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2084"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2132"/>
        <source>Quit application</source>
        <translation> Chiudi l&apos;applicazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2135"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2142"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="525"/>
        <source>About MX Conky</source>
        <translation>Informazioni su MX Conky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>Version: </source>
        <translation>Versione:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="527"/>
        <source>GUI program for configuring Conky in MX Linux</source>
        <translation>Programma per la configurazione di Conky in MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="529"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="530"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="531"/>
        <location filename="../mainwindow.cpp" line="544"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="532"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="552"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="571"/>
        <source>MX Conky Help</source>
        <translation>Aiuto per MX Conky</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="57"/>
        <location filename="../mainwindow.cpp" line="690"/>
        <source>Select Conky Manager config file</source>
        <translation>Seleziona il file config di Conky Manager</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Conky Data Update</source>
        <translation>Aggiornamento Concky-Data</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>The MX Conky data set has been updated. &lt;p&gt;&lt;p&gt;                                  Copy from the folder where it is located &lt;a href=&quot;/usr/share/mx-conky-data/themes&quot;&gt;/usr/share/mx-conky-data/themes&lt;/a&gt;                                   whatever you wish to your Home hidden conky folder &lt;a href=&quot;%1/.conky&quot;&gt;~/.conky&lt;/a&gt;.                                   Be careful not to overwrite any conkies you have changed.</source>
        <translation>L&apos;insieme dei dati di MX Conky è stato aggiornato. &lt;p&gt;&lt;p&gt;                                  Copia dalla cartella dove sono archiviati &lt;a href=&quot;/usr/share/mx-conky-data/themes&quot;&gt;/usr/share/mx-conky-data/themes&lt;/a&gt;                                   qualsiasi cosa ti possa interessare sulla cartella nascosta presente nella Home &lt;a href=&quot;%1/.conky&quot;&gt;~/.conky&lt;/a&gt;.                                   Fa attenzione a non sovrascrivere i conkies che hai modificato.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="104"/>
        <location filename="../main.cpp" line="135"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="105"/>
        <source>Could not find conky-manager, please install it before running mx-conky</source>
        <translation>Non si riesce a trovare conky-manager, installalo prima di eseguire mx-conky</translation>
    </message>
    <message>
        <source>No file was selected, quiting program</source>
        <translation type="vanished">Nessun file è stato selezionato, si chiude il programma</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="136"/>
        <source>You must run this program as normal user</source>
        <translation>Devi avviare questo programma come utente normale</translation>
    </message>
</context>
</TS>
